pub struct ExternalLinkPart {
pub external_book: Option<CtExternalBook>,
}Fields
external_book: Option<CtExternalBook>Trait Implementations
Sourceimpl Debug for ExternalLinkPart
impl Debug for ExternalLinkPart
Sourceimpl XmlDeserialize for ExternalLinkPart
impl XmlDeserialize for ExternalLinkPart
fn deserialize<B: BufRead>( tag: &[u8], reader: &mut Reader<B>, attrs: Attributes<'_>, is_empty: bool, ) -> Self
fn de_root() -> Option<&'static [u8]>
A helper function used when ty =
untag. It could help
us to find out the children tags when deserializingSourcefn __deserialize_from_unparsed_array(
array: Vec<(&'static [u8], Unparsed)>,
) -> Self
fn __deserialize_from_unparsed_array( array: Vec<(&'static [u8], Unparsed)>, ) -> Self
A helper function used when handling the untag types. Read more
fn __deserialize_from_text(_: &str) -> Option<Self>where
Self: Sized,